/*
 * Léon - The URL Cleaner
 * Copyright (C) 2024 Sven Jacobs
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package com.svenjacobs.app.leon.ui.common.views

import androidx.compose.foundation.layout.statusBarsPadding
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.automirrored.filled.ArrowBack
import androidx.compose.material3.CenterAlignedTopAppBar
import androidx.compose.material3.Icon
import androidx.compose.material3.IconButton
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Modifier
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.text.style.TextOverflow
import com.svenjacobs.app.leon.R

@Composable
fun TopAppBar(modifier: Modifier = Modifier, onBackClick: (() -> Unit)? = null) {
	CenterAlignedTopAppBar(
		modifier = modifier.statusBarsPadding(),
		title = {
			Text(
				text = stringResource(R.string.scaffold_title),
				overflow = TextOverflow.Ellipsis,
				maxLines = 1,
			)
		},
		navigationIcon = { if (onBackClick != null) NavigationIcon(onClick = onBackClick) },
	)
}

@Composable
private fun NavigationIcon(modifier: Modifier = Modifier, onClick: () -> Unit) {
	IconButton(
		modifier = modifier,
		onClick = onClick,
	) {
		Icon(
			Icons.AutoMirrored.Filled.ArrowBack,
			contentDescription = stringResource(R.string.a11y_back_navigation),
		)
	}
}
