/*
 * Léon - The URL Cleaner
 * Copyright (C) 2023 Sven Jacobs
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package com.svenjacobs.app.leon.core.domain.inject

import android.content.Context
import com.svenjacobs.app.leon.core.domain.sanitizer.SanitizerRepository
import com.svenjacobs.app.leon.core.domain.sanitizer.SanitizersCollection

object DomainContainer {

	fun init(
		appContext: Context,
		sanitizerRepositoryProvider: () -> SanitizerRepository,
		sanitizers: SanitizersCollection,
	) {
		this.AppContext = appContext
		this.SanitizerRepositoryProvider = sanitizerRepositoryProvider
		this.Sanitizers = sanitizers
	}

	private lateinit var SanitizerRepositoryProvider: () -> SanitizerRepository

	lateinit var AppContext: Context
		private set

	lateinit var Sanitizers: SanitizersCollection
		private set

	val SanitizerRepository: SanitizerRepository by lazy { SanitizerRepositoryProvider() }
}
